#ifndef SYSTEMINIT_H_
#define SYSTEMINIT_H

/*************************************************************************************************************************
									File Details
**************************************************************************************************************************
	File name 							: SystemInit.h
	
	Purpose								: This file has include file, macros, and function declaration corresponding to 
										  Parallel_FLASH.C file
										  
	Author								: Mitesh Moonat & Harshit Gaharwar
	
	VDSP version used for testing		: VisualDSP++5.0, update 10
										  
	Hardware used						: ADSP-21469, ADSP-21479, ADSP-21489, ADSP-21375, ADSP-21369 EZ-Kits 
										  and ADSP-21469, ADPS-21367, ADSP-21375 BUBs
	
	Connection details 					: See "main.C"
	
	Guidelines for change				: No change required when using EZ-Kits. For custom board,  change the macros
										  SDCTL_VALUE, SDRRC_VALUE, EPCTL_VALUE,  AMICTL_VALUE  accordingly
					
**************************************************************************************************************************/

/*************************************************************************************************************************
									Include Files
**************************************************************************************************************************/

#include  "EPInit.h"
#include "sru.h"

//Processor specific definitons 
#if defined(__ADSP21262__)
	#include "def21262.h"
	#include "Cdef21262.h"

#elif defined (__ADSP21261__)
	#include "def21261.h"
	#include "Cdef21261.h"

#elif defined (__ADSP21266__)
	#include "def21266.h"
	#include "Cdef21266.h"

#elif defined (__ADSP21267__)
	#include "def21267.h"
	#include "Cdef21267.h"

#elif defined (__ADSP21362__)
	#include "def21362.h"
	#include "Cdef21362.h"

#elif defined (__ADSP21363__)
	#include "def21363.h"
	#include "Cdef21363.h"

#elif defined (__ADSP21364__)
	#include "def21364.h"
	#include "Cdef21364.h"

#elif defined (__ADSP21365__)
	#include "def21365.h"
	#include "Cdef21365.h"

#elif defined (__ADSP21366__)
	#include "def21366.h"
	#include "Cdef21366.h"

#elif defined (__ADSP21367__)
	#include "def21367.h"
	#include "Cdef21367.h"

#elif defined (__ADSP21368__)
	#include "def21368.h"
	#include "Cdef21368.h"

#elif defined (__ADSP21369__)
	#include "def21369.h"
	#include "Cdef21369.h"

#elif defined (__ADSP21375__)
	#include "def21375.h"
	#include "Cdef21375.h"

#elif defined (__ADSP21371__)
	#include "def21371h"
	#include "Cdef21371.h"

#elif defined (__ADSP21462__)
	#include "def21462.h"
	#include "Cdef21462.h"

#elif defined (__ADSP21465__)
	#include "def21465.h"
	#include "Cdef21465.h"

#elif defined (__ADSP21467__)
	#include "def21467.h"
	#include "Cdef21467.h"

#elif defined (__ADSP21469__)
	#include "def21469.h"
	#include "Cdef21469.h"

#elif defined (__ADSP21471__)
	#include "def21471.h"
	#include "Cdef21471.h"

#elif defined (__ADSP21472__)

	#include "def21472.h"
	#include "Cdef21472.h"

#elif defined (__ADSP21475__)
	#include "def21475.h"
	#include "Cdef21475.h"

#elif defined (__ADSP21478__)
	#include "def21478.h"
	#include "Cdef21478.h"

#elif defined (__ADSP21479__)
	#include "def21479.h"
	#include "Cdef21479.h"

#elif defined (__ADSP21481__)
	#include "def21481.h"
	#include "Cdef21481.h"

#elif defined (__ADSP21482__)
	#include "def21482.h"
	#include "Cdef21482.h"

#elif defined (__ADSP21483__)
	#include "def21483.h"
	#include "Cdef21483.h"

#elif defined (__ADSP21485__)
	#include "def21485.h"
	#include "Cdef21485.h"

#elif defined (__ADSP21486__)
	#include "def21486.h"
	#include "Cdef21486.h"

#elif defined (__ADSP21487__)
	#include "def21487.h"
	#include "Cdef21487.h"

#elif defined (__ADSP21488__)
	#include "def21488.h"
	#include "Cdef21488.h"

#elif defined (__ADSP21489__)
	#include "def21489.h"
	#include "Cdef21489.h"
	
#endif


/*************************************************************************************************************************
									MACROs
*************************************************************************************************************************/
#define NOP asm volatile("nop;")

#define DDR2TRFC29 (0x1D << 21)  // RFC bits are available on bits 21:28 of the DD2CTL4
#define RDIV	(0x6CD)
#define dll_lock_period 3000  // 512 DDCLK cycles

#define SDMODIFY 1


#if defined(__ADSP21367__) || defined(__ADSP21368__) || defined(__ADSP21369__) 

	#define HC3 (BIT_11)|(BIT_12)
	#define RHC3 (BIT_18)|(BIT_19)

	#define SDCTL_VALUE 	SDCL3|DSDCLK1|SDPSS|SDCAW8|SDRAW12|SDTRAS7|SDTRP3|SDTWR2|SDTRCD3
	#define SDRRC_VALUE 	(0xA17)|(SDMODIFY<<17)|SDROPT
	#define EPCTL_VALUE  	B2SD 
	#define AMICTL_VALUE	BW8|AMIEN|WS31|HC3|RHC3|IC7|PKDIS
	

#endif

#if defined(__ADSP21371__)

	#define HC3 (BIT_11)|(BIT_12)
	#define RHC3 (BIT_18)|(BIT_19)


	#define SDCTL_VALUE 	SDNOBSTOP|SDCL3|DSDCLK1|SDPSS|SDCAW9|SDRAW12|SDTRAS7|SDTRP3|SDTWR2|SDTRCD3
	#define SDRRC_VALUE 	(0x6AD)|(SDMODIFY<<17)|SDROPT
	#define EPCTL_VALUE  	B0SD 	
	#define AMICTL_VALUE	BW8|AMIEN|WS31|HC3|RHC3|IC7|PKDIS


#endif

#if defined(__ADSP21375__)

	#define HC3 (BIT_11)|(BIT_12)
	#define RHC3 (BIT_18)|(BIT_19)


	#define SDCTL_VALUE 	SDNOBSTOP|SDCL3|DSDCLK1|SDPSS|SDCAW9|SDRAW12|SDTRAS6|SDTRP3|SDTWR2|SDTRCD3|X16DE
	#define SDRRC_VALUE 	(0x7F7)|(SDMODIFY<<17)|SDROPT
	#define EPCTL_VALUE  	B0SD 	
	#define AMICTL_VALUE	BW8|AMIEN|WS31|HC3|RHC3|IC7|PKDIS

#endif

#if defined(__2146x__) 
	#define AMICTL_VALUE	BW8|AMIEN|WS31|PKDIS|HC3|IC7|RHC3
#endif

#if defined(__2147x__) 

	#define SDCTL_VALUE 	SDCL3|SDPSS|SDCAW9|SDRAW13|SDTRAS6|SDTRP3|SDTWR2|SDTRCD3|X16DE
	#define SDRRC_VALUE 	(0x406)|(SDMODIFY<<17)|SDROPT
	#define EPCTL_VALUE  	B0SD 	
	#define AMICTL_VALUE	BW8|AMIEN|WS31|PKDIS
#endif

#if defined(__2148x__)

	#define SDCTL_VALUE 	SDCL3|SDPSS|SDCAW9|SDRAW13|SDTRAS7|SDTRP3|SDTWR2|SDTRCD3|X16DE
	#define SDRRC_VALUE 	(0x4D8)|(SDMODIFY<<17)|SDROPT
	#define EPCTL_VALUE  	B0SD 
	#define AMICTL_VALUE	BW8|AMIEN|WS31|PKDIS

#endif

/*************************************************************************************************************************
									Function Declarations
**************************************************************************************************************************/
void Init_PLL(void);

#if defined(__ADSP21367__) || defined(__ADSP21368__) || \
    	defined(__ADSP21369__) || defined(__2137x__) || defined(__214xx__)
	void Init_DRAM(void);

#endif
void Setup_System_For_FLASH(void);
/************************************************************************************************************************/
#endif

/**************************************** END OF FILE*********************************************************************/
